%define srcname   %{name}-c
%define major_c   18
%define libname   %mklibname %{name} %{major_c}
%define develname %mklibname %{name} -d

Summary:	Libraries to use the Unidata network Common Data Form (netCDF)
Name:		netcdf
Version:	4.7.4
Release:	%mkrel 3
Group:		Development/C
License:	BSD
URL:		http://www.unidata.ucar.edu/software/netcdf/
Source0:	https://github.com/Unidata/netcdf-c/archive/v%{version}/%{srcname}-%{version}.tar.gz
Patch0:		netcdf-c-pr1871.patch
Patch1:		hdf5-cd_nelems.patch

Requires(post): info-install
Requires(postun): info-install
BuildRequires:	hdf5-devel
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	valgrind
BuildRequires:	texinfo
BuildRequires:	tetex-latex
BuildRequires:	groff

%description
NetCDF (network Common Data Form) is an interface for array-oriented data
access and a freely-distributed collection of software libraries for C,
Fortran, C++, and perl that provides an implementation of the interface.
The netCDF library also defines a machine-independent format for representing
scientific data. Together, the interface, library, and format support the
creation, access, and sharing of scientific data. The netCDF software was
developed at the Unidata Program Center in Boulder, Colorado.

NetCDF data is:

   o Self-Describing. A netCDF file includes information about the data it
     contains.

   o Network-transparent. A netCDF file is represented in a form that can be
     accessed by computers with different ways of storing integers, characters,
     and floating-point numbers.

   o Direct-access. A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding data.

   o Appendable. Data can be appended to a netCDF dataset along one dimension
     without copying the dataset or redefining its structure. The structure of
     a netCDF dataset can be changed, though this sometimes causes the dataset
     to be copied.

   o Sharable. One writer and multiple readers may simultaneously access the
     same netCDF file.

%package -n	%{libname}
Summary:	C libraries for netcdf-4
Group:		System/Libraries
Provides:	lib%{name} = %{version}
Requires:	hdf5 = %{_hdf5_version}

%description -n	%{libname}
This package contains the netCDF-4 C libraries.

%package -n	%{develname}
Summary:	Development files for netcdf-4
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 4.0
Conflicts:	%{name} < 4.1
Conflicts:	%{mklibname %{name} 7}

%description -n %{develname}
This package contains the netCDF-4 header files, shared devel libs, and
man pages.

%prep
%setup -q -n %{srcname}-%{version}
%autopatch -p1

%build
%configure --enable-shared --disable-static \
		--enable-netcdf-4 \
		--enable-dap \
           	--enable-extra-example-tests \
		--disable-dap-remote-tests
		
#parallel make is buggy
%{__make} %{_make_output_sync}

%check
make check || ( cat */test-suite.log && exit 1 )

%install
%make_install

find %{buildroot} -name '*.la' -delete

%files
%doc COPYRIGHT README.md RELEASE_NOTES.md
%{_bindir}/ncgen
%{_bindir}/ncgen3
%{_bindir}/ncdump
%{_bindir}/nccopy
%{_mandir}/man1/*.1*


%files -n %{libname}
%{_libdir}/libnetcdf.so.%{major_c}{,.*}

%files -n %{develname}
%{_bindir}/nc-config
%{_includedir}/*.h
%{_libdir}/*.so
%{_mandir}/man3/*.3*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libnetcdf.settings


%changelog
* Sun Oct 25 2020 pterjan <pterjan> 4.7.4-3.mga8
+ Revision: 1639337
- Fix a bug in hdf5 code which was made visible by hdf5 1.10.7 on arm but is there everywhere
- Update to 4.7.4
- Switch to upstream patch for unaligned reads
+ akien <akien>
- Update upstream patch to fix arm unaligned access
- Add explicit versioning for hdf5 dep, as a rebuild is necessary on each version change

* Thu Oct 01 2020 pterjan <pterjan> 4.7.3-3.mga8
+ Revision: 1631460
- Fix some unaligned reads breaking on arm

* Tue Sep 29 2020 tv <tv> 4.7.3-2.mga8
+ Revision: 1631217
- we've valgrind on arm
+ pterjan <pterjan>
- Fix displaying of failed tests logs

* Sun Mar 08 2020 pterjan <pterjan> 4.7.3-1.mga8
+ Revision: 1554944
- Update to 4.7.3

* Sat Feb 15 2020 umeabot <umeabot> 4.6.1-6.mga8
+ Revision: 1526052
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Apr 23 2019 daviddavid <daviddavid> 4.6.1-5.mga7
+ Revision: 1394992
- rebuild for new hdf5 1.10.5

* Thu Nov 08 2018 daviddavid <daviddavid> 4.6.1-4.mga7
+ Revision: 1328904
- rebuild for new hdf5 1.10.4

* Sun Sep 23 2018 umeabot <umeabot> 4.6.1-3.mga7
+ Revision: 1299702
- Mageia 7 Mass Rebuild

* Thu Aug 02 2018 tv <tv> 4.6.1-2.mga7
+ Revision: 1246851
- fix upgrade

* Wed Aug 01 2018 eatdirt <eatdirt> 4.6.1-1.mga7
+ Revision: 1246619
- Upgrade to version 4.6.1

* Fri Apr 27 2018 wally <wally> 4.3.3.1-3.mga7
+ Revision: 1222942
- rebuild for new hdf5

* Tue Feb 16 2016 umeabot <umeabot> 4.3.3.1-2.mga6
+ Revision: 961729
- Mageia 6 Mass Rebuild

* Thu Aug 13 2015 fwang <fwang> 4.3.3.1-1.mga6
+ Revision: 864207
- 4.3.3.1

* Tue Jul 21 2015 daviddavid <daviddavid> 4.3.3-2.mga6
+ Revision: 855864
- rebuild with new hdf5

* Wed Jul 01 2015 joequant <joequant> 4.3.3-1.mga6
+ Revision: 849304
- upgrade to 4.3.3

* Wed Oct 15 2014 umeabot <umeabot> 4.3.2-3.mga5
+ Revision: 739814
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.3.2-2.mga5
+ Revision: 682845
- Mageia 5 Mass Rebuild

* Sun Jul 06 2014 pterjan <pterjan> 4.3.2-1.mga5
+ Revision: 645974
- 4.3.2

* Sat Oct 19 2013 umeabot <umeabot> 4.3.0-3.mga4
+ Revision: 530082
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 fwang <fwang> 4.3.0-2.mga4
+ Revision: 455003
- rebuild for new hdf5

* Wed Jun 26 2013 fwang <fwang> 4.3.0-1.mga4
+ Revision: 446779
- new version 4.3.0

* Mon Mar 11 2013 rtp <rtp> 4.2.1.1-4.mga3
+ Revision: 402083
- disable valgrind on arm/mips
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 12 2012 fwang <fwang> 4.2.1.1-2.mga3
+ Revision: 305116
- rebuild for new hdf5

* Wed Sep 19 2012 fwang <fwang> 4.2.1.1-1.mga3
+ Revision: 296140
- cleanup spec
- upload patch
- rediff pkgconfig patch
- new version 4.2.1.1

* Fri Apr 06 2012 fwang <fwang> 4.1.3-3.mga2
+ Revision: 228846
- rebuild for new gcc (bug#5228)
- fix provides
- update file list
- new verison 4.1.3
+ dmorgan <dmorgan>
- Rebuild against new hdf5

* Thu Feb 17 2011 ahmad <ahmad> 4.1.1-3.mga1
+ Revision: 53318
- drop old/unneeded scriptlets
- imported package netcdf

